@@ -28,7 +28,11 @@
 #include <pk-backend.h>
 #include <pk-backend-spawn.h>
 
+#include <apt-pkg/aptconfiguration.h>
+#include <apt-pkg/error.h>
+#include <apt-pkg/fileutl.h>
 #include <apt-pkg/init.h>
+#include <apt-pkg/pkgsystem.h>
 
 #include "apt-intf.h"
 #include "apt-cache-file.h"
@@ -245,11 +249,6 @@ void pk_backend_required_by(PkBackend *backend,
     pk_backend_job_thread_create(job, backend_depends_on_or_requires_thread, NULL, NULL);
 }
 
-void pk_backend_get_distro_upgrades(PkBackend *backend, PkBackendJob *job)
-{
-    pk_backend_spawn_helper(spawn, job, "get-distro-upgrade.py", "get-distro-upgrades", NULL);
-}
-
 static void backend_get_files_thread(PkBackendJob *job, GVariant *params, gpointer user_data)
 {
     gchar **package_ids;
@@ -385,11 +384,17 @@ static void backend_get_updates_thread(PkBackendJob *job, GVariant *params, gpoi
     pk_backend_job_set_status(job, PK_STATUS_ENUM_QUERY);
 
     PkgList updates;
+    PkgList installs;
+    PkgList removals;
+    PkgList obsoleted;
     PkgList downgrades;
     PkgList blocked;
-    updates = apt->getUpdates(blocked, downgrades);
+    updates = apt->getUpdates(blocked, downgrades, installs, removals, obsoleted);
 
     apt->emitUpdates(updates, filters);
+    apt->emitPackages(installs, filters, PK_INFO_ENUM_INSTALLING);
+    apt->emitPackages(removals, filters, PK_INFO_ENUM_REMOVING);
+    apt->emitPackages(obsoleted, filters, PK_INFO_ENUM_OBSOLETING);
     apt->emitPackages(downgrades, filters, PK_INFO_ENUM_DOWNGRADING);
     apt->emitPackages(blocked, filters, PK_INFO_ENUM_BLOCKED);
 }
@@ -1087,10 +1092,5 @@ PkBitfield pk_backend_get_roles(PkBackend *backend)
                 PK_ROLE_ENUM_INSTALL_FILES,
                 -1);
 
-    // only add GetDistroUpgrades if the binary is present
-    if (g_file_test(PREUPGRADE_BINARY, G_FILE_TEST_EXISTS)) {
-        pk_bitfield_add(roles, PK_ROLE_ENUM_GET_DISTRO_UPGRADES);
-    }
-
     return roles;
 }
