@@ -222,14 +222,14 @@ ROLE_ACCEPT_EULA = "accept-eula"
 ROLE_CANCEL = "cancel"
 ROLE_DOWNLOAD_PACKAGES = "download-packages"
 ROLE_GET_CATEGORIES = "get-categories"
-ROLE_GET_DEPENDS = "get-depends"
+ROLE_GET_DEPENDS = "depends-on"
 ROLE_GET_DETAILS = "get-details"
 ROLE_GET_DISTRO_UPGRADES = "get-distro-upgrades"
 ROLE_GET_FILES = "get-files"
 ROLE_GET_OLD_TRANSACTIONS = "get-old-transactions"
 ROLE_GET_PACKAGES = "get-packages"
 ROLE_GET_REPO_LIST = "get-repo-list"
-ROLE_GET_REQUIRES = "get-requires"
+ROLE_GET_REQUIRES = "required-by"
 ROLE_GET_UPDATES = "get-updates"
 ROLE_GET_UPDATE_DETAIL = "get-update-detail"
 ROLE_INSTALL_FILES = "install-files"
