@@ -135,11 +135,13 @@ pk_client_helper_child_free (PkClientHelperChild *child)
 gboolean
 pk_client_helper_stop (PkClientHelper *client_helper, GError **error)
 {
-	PkClientHelperPrivate *priv = client_helper->priv;
+	PkClientHelperPrivate *priv = NULL;
 
 	g_return_val_if_fail (PK_IS_CLIENT_HELPER (client_helper), FALSE);
 	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
+	priv = client_helper->priv;
+
 	/* make sure started */
 	g_return_val_if_fail (priv->socket_file != NULL, FALSE);
 
@@ -418,8 +420,7 @@ pk_client_helper_start (PkClientHelper *client_helper,
 {
 	guint i;
 	gboolean use_kde_helper = FALSE;
-	gint fd;
-	PkClientHelperPrivate *priv = client_helper->priv;
+	PkClientHelperPrivate *priv = NULL;
 	g_autoptr(GError) error_local = NULL;
 	g_autoptr(GSocketAddress) address = NULL;
 
@@ -429,6 +430,8 @@ pk_client_helper_start (PkClientHelper *client_helper,
 	g_return_val_if_fail (socket_filename != NULL, FALSE);
 	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
+	priv = client_helper->priv;
+
 	/* make sure not been started before */
 	g_return_val_if_fail (priv->argv == NULL, FALSE);
 	g_return_val_if_fail (priv->socket_file == NULL, FALSE);
@@ -454,10 +457,6 @@ pk_client_helper_start (PkClientHelper *client_helper,
 		}
 	}
 
-	/* cache for actual start */
-	priv->argv = g_strdupv (argv);
-	priv->envp = g_strdupv (envp);
-
 	/* create socket */
 	priv->socket = g_socket_new (G_SOCKET_FAMILY_UNIX, G_SOCKET_TYPE_STREAM, G_SOCKET_PROTOCOL_DEFAULT, error);
 	if (priv->socket == NULL)
@@ -470,6 +469,7 @@ pk_client_helper_start (PkClientHelper *client_helper,
 
 	/* spawn KDE debconf communicator */
 	if (use_kde_helper) {
+		priv->envp = g_strdupv (envp);
 		priv->argv = g_new0 (gchar *, 2);
 		priv->argv[0] = g_strdup ("/usr/bin/debconf-kde-helper");
 		priv->argv[1] = g_strconcat ("--socket-path", "=", socket_filename, NULL);
@@ -487,6 +487,52 @@ pk_client_helper_start (PkClientHelper *client_helper,
 	if (!g_socket_listen (priv->socket, error))
 		return FALSE;
 
+	return pk_client_helper_start_with_socket (client_helper, priv->socket, argv, envp, error);
+}
+
+/**
+ * pk_client_helper_start_with_socket:
+ * @client_helper: a valid #PkClientHelper instance
+ * @socket: the (bound and listening) #GSocket instance to use
+ * @argv: the executable, along with any arguments
+ * @envp: the environment
+ * @error: A #GError or %NULL
+ *
+ * Starts the helper process, by running the helper process and setting
+ * up the socket for use.
+ *
+ * Return value: %TRUE for success
+ *
+ * Since: 1.1.13
+ **/
+gboolean
+pk_client_helper_start_with_socket (PkClientHelper *client_helper,
+				    GSocket *socket,
+				    gchar **argv, gchar **envp,
+				    GError **error)
+{
+	gint fd;
+	PkClientHelperPrivate *priv = NULL;
+	g_autoptr(GError) error_local = NULL;
+	g_autoptr(GSocketAddress) address = NULL;
+
+	g_return_val_if_fail (PK_IS_CLIENT_HELPER (client_helper), FALSE);
+	g_return_val_if_fail (socket != NULL, FALSE);
+	g_return_val_if_fail (argv != NULL, FALSE);
+	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
+
+	priv = client_helper->priv;
+
+	/* make sure not been started before */
+	g_return_val_if_fail (priv->argv == NULL, FALSE);
+
+	/* cache for actual start */
+	priv->argv = g_strdupv (argv);
+	priv->envp = g_strdupv (envp);
+
+	/* Set the socket */
+	priv->socket = socket;
+
 	/* socket has data */
 	fd = g_socket_get_fd (priv->socket);
 	priv->socket_channel = g_io_channel_unix_new (fd);
@@ -495,6 +541,34 @@ pk_client_helper_start (PkClientHelper *client_helper,
 	return TRUE;
 }
 
+/**
+ * pk_client_helper_is_active:
+ * @client_helper: a valid #PkClientHelper instance
+ *
+ * Return value: TRUE if there is an accepted connection, FALSE
+ *               otherwise.
+ *
+ * Since: 1.1.13
+ */
+gboolean
+pk_client_helper_is_active (PkClientHelper *client_helper)
+{
+	PkClientHelperPrivate *priv;
+
+	g_return_val_if_fail (PK_IS_CLIENT_HELPER (client_helper), FALSE);
+
+	priv = client_helper->priv;
+
+	for (guint i = 0; i < priv->children->len; i++) {
+		PkClientHelperChild *child = g_ptr_array_index (priv->children, i);
+		if (!g_source_is_destroyed (child->socket_channel_source) &&
+		    !g_source_is_destroyed (child->stdout_channel_source))
+			return TRUE;
+	}
+
+	return FALSE;
+}
+
 /*
  * pk_client_helper_class_init:
  **/
