@@ -59,9 +59,6 @@ timed_exit_cb (GMainLoop *mainloop)
 	return FALSE;
 }
 
-/**
- * pk_main_timeout_check_cb:
- **/
 static gboolean
 pk_main_timeout_check_cb (PkMainHelper *helper)
 {
@@ -76,9 +73,6 @@ pk_main_timeout_check_cb (PkMainHelper *helper)
 	return TRUE;
 }
 
-/**
- * pk_main_quit_cb:
- **/
 static void
 pk_main_quit_cb (PkEngine *engine, GMainLoop *mainloop)
 {
@@ -86,9 +80,6 @@ pk_main_quit_cb (PkEngine *engine, GMainLoop *mainloop)
 	g_main_loop_quit (mainloop);
 }
 
-/**
- * pk_main_sigint_cb:
- **/
 static gboolean
 pk_main_sigint_cb (gpointer user_data)
 {
@@ -98,14 +89,12 @@ pk_main_sigint_cb (gpointer user_data)
 	return FALSE;
 }
 
-/**
- * main:
- **/
 int
 main (int argc, char *argv[])
 {
 	GMainLoop *loop = NULL;
 	GOptionContext *context;
+	PkMainHelper helper;
 	gboolean ret = TRUE;
 	gboolean disable_timer = FALSE;
 	gboolean version = FALSE;
@@ -113,7 +102,6 @@ main (int argc, char *argv[])
 	gboolean immediate_exit = FALSE;
 	gboolean keep_environment = FALSE;
 	gint exit_idle_time;
-	guint timer_id = 0;
 	g_autoptr(GError) error = NULL;
 	g_autofree gchar *backend_name = NULL;
 	g_autofree gchar *conf_filename = NULL;
@@ -190,6 +178,8 @@ main (int argc, char *argv[])
 
 	/* after how long do we timeout? */
 	exit_idle_time = g_key_file_get_integer (conf, "Daemon", "ShutdownTimeout", NULL);
+	if (exit_idle_time == 0)
+		exit_idle_time = 300;
 	g_debug ("daemon shutdown set to %i seconds", exit_idle_time);
 
 	/* override the backend name */
@@ -239,13 +229,11 @@ main (int argc, char *argv[])
 
 	/* only poll when we are alive */
 	if (exit_idle_time > 0 && !disable_timer) {
-		PkMainHelper helper;
 		helper.engine = engine;
 		helper.exit_idle_time = exit_idle_time;
 		helper.loop = loop;
 		helper.timer_id = g_timeout_add_seconds (5, (GSourceFunc) pk_main_timeout_check_cb, &helper);
 		g_source_set_name_by_id (helper.timer_id, "[PkMain] main poll");
-		timer_id = helper.timer_id;
 	}
 
 	/* immediatly exit */
@@ -259,8 +247,8 @@ out:
 	syslog (LOG_DAEMON | LOG_DEBUG, "daemon quit");
 	closelog ();
 
-	if (timer_id > 0)
-		g_source_remove (timer_id);
+	if (helper.timer_id > 0)
+		g_source_remove (helper.timer_id);
 	if (loop != NULL)
 		g_main_loop_unref (loop);
 exit_program:
